// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/FinalState.hh"
#include "Rivet/Projections/UnstableFinalState.hh"

namespace Rivet {


  class ALICE_2012_I1097057 : public Analysis {
  public:

    ALICE_2012_I1097057()
      : Analysis("ALICE_2012_I1097057")
    {    }

    void init() {
        const UnstableFinalState ufs(Cuts::abseta < 15);
        addProjection(ufs, "UFS");
        
        _histPtOmega      = bookHisto1D(1, 1, 1);
        _histPtAntiOmega  = bookHisto1D(1, 1, 2);
        _histPtXi         = bookHisto1D(2, 1, 1);
        _histPtAntiXi     = bookHisto1D(2, 1, 2);
        _temp_h_Omegas    = bookHisto1D("TMP/h_Omegas", refData(3, 1, 1));
        _temp_h_Xis       = bookHisto1D("TMP/h_Xis", refData(3, 1, 1));
        _h_OmegaXi        = bookScatter2D(3, 1, 1);
    }

      
    void analyze(const Event& event) {
      const double weight = event.weight();
        const UnstableFinalState& ufs = applyProjection<UnstableFinalState>(event, "UFS");
        
        foreach (const Particle& p, ufs.particles()) {
            const double absrap = p.absrap();
            const double pT = p.pT()/GeV;
            const double m0 = p.mass()/GeV;
            const double mTm0 = sqrt(pT*pT+m0*m0)-m0;
            
            if (absrap < 0.5) {
                switch(p.pid()) {
                    case 3334:
                        _histPtOmega->fill(pT, weight);
                        _temp_h_Omegas->fill(mTm0, weight);
                        break;
                    case -3334:
                        _histPtAntiOmega->fill(pT, weight);
                        _temp_h_Omegas->fill(mTm0, weight);
                        break;
                    case 3312:
                        _histPtXi->fill(pT, weight);
                        _temp_h_Xis->fill(mTm0, weight);
                        break;
                    case -3312:
                        _histPtAntiXi->fill(pT, weight);
                        _temp_h_Xis->fill(mTm0, weight);
                        break;
                }
            }
        }
    }

    void finalize() {
        scale(_histPtOmega,     1./sumOfWeights());
        scale(_histPtAntiOmega, 1./sumOfWeights());
        scale(_histPtXi,        1./sumOfWeights());
        scale(_histPtAntiXi,    1./sumOfWeights());
        divide(_temp_h_Omegas, _temp_h_Xis, _h_OmegaXi);
    }

  private:

      Histo1DPtr _histPtOmega, _histPtAntiOmega, _histPtXi, _histPtAntiXi;
      Histo1DPtr _temp_h_Omegas, _temp_h_Xis;
      Scatter2DPtr _h_OmegaXi;
      
  };

  // The hook for the plugin system
  DECLARE_RIVET_PLUGIN(ALICE_2012_I1097057);


}
